@@ -65,197 +65,6 @@
 NULL
 
 
-
-#' Reference table - for Automated Land Program National Forests.
-#' 
-#' National Forest region and names from the USDA S_USA.BasicOwnershipFS
-#' (Surface Ownership Parcels) attribute table. An area depicted as surface
-#' ownership parcels dissolved on the same ownership classification
-#' 
-#' 
-#' @name ref_ALP
-#' @docType data
-#' @format A dataframe with 2 columns, R1 and FORESTNAME.
-#' @note ## ALP National Forest boundary alp_dsn <-
-#' "S_USA.BasicOwnershipFS.gdb" alp_layer <- "BasicOwnershipFS" alp.att <-
-#' "FORESTNAME" alp_bnd <- spImportSpatial(dsn=alp_dsn, layer=alp_layer)
-#' alp_names <- unique(sf::st_drop_geometry(alp_bnd[, c("REGION",
-#' "FORESTNAME")])) alp_names <- alp_names[order(alp_names$REGION,
-#' alp_names$FORESTNAME),] alp_names <- alp_names[grepl("National Forest",
-#' alp_names$FORESTNAME)==TRUE,] alp_names$FORESTNAME <- sub(" National
-#' Forest", "", alp_names$FORESTNAME)
-#' 
-#' Ownership classes that are not USDA Forest Service were removed from the
-#' layer.\cr OWNERCLASSIFICATION = "USDA FOREST SERVICE" subset with following
-#' query alpfs <- alpfs[!is.na(alpfs$OWNERCLASSIFICATION) &
-#' alpfs$OWNERCLASSIFICATION != 'NON-FS',]
-#' @source Downloaded from the USDA Forest Service FSGeodata Clearinghose on
-#' 2020 June 3, format ESRI geodatabase
-#' (https://data.fs.usda.gov/geodata/edw/datasets.php?xmlKeyword=surface+ownership)
-#' 
-#' U.S. Forest Service, Automated Land Program (ALP) Publication Date:
-#' 2020-05-26.
-#' @keywords datasets
-NULL
-
-
-
-#' Reference table - Metadata for cond default variables output from
-#' DBgetPlots()
-#' 
-#' Data frame with variable names and descriptions
-#' 
-#' 
-#' @name ref_cond
-#' @docType data
-#' @format A data frame with 61 rows and 3 columns VARIABLE - Variable in cond
-#' data frame DESCRIPTION - Description of variable in cond data frame TABLE -
-#' Table in database where variable originates or if derived
-#' @references O'Connell, B.M.; LaPoint, E.B.; Turner, J.A.; Ridley, T.; Boyer,
-#' D.; Wilson, A.M.; Waddell, K.L.; Christensen, G.; Conkling, B.L. 2012. The
-#' Forest Inventory and Analysis Database: Database Description and Users
-#' Manual Version 5.1.2 for Phase 2. U.S. Department of Agriculture.
-#' (http://fia.fs.fed.us/library/database-documentation/current/ver5-2012/FIADB_user
-#' manual_5-1-2_p2_07_2012.pdf)
-#' @source FIA look-up table
-#' @keywords datasets
-NULL
-
-
-
-#' Reference table - for generating tables.
-#' 
-#' Table conversion factors from English to metric units.
-#' 
-#' 
-#' @name ref_conversion
-#' @docType data
-#' @format A dataframe with 4 columns: TYPE, ENGLISH, METRIC, CONVERSION.
-#' @source Conversion table.
-#' @keywords datasets
-NULL
-
-
-
-#' Reference table - Metadata for plt default variables output from
-#' DBgetPlots()
-#' 
-#' Data frame with variable names and descriptions.
-#' 
-#' 
-#' @name ref_plt
-#' @docType data
-#' @format A data frame with 43 rows and 3 columns VARIABLE - Variable in plt
-#' data frame DESCRIPTION - Description of variable in plt data frame TABLE -
-#' Table in database where variable originates or if derived
-#' @references O'Connell, B.M.; LaPoint, E.B.; Turner, J.A.; Ridley, T.; Boyer,
-#' D.; Wilson, A.M.; Waddell, K.L.; Christensen, G.; Conkling, B.L. 2012. The
-#' Forest Inventory and Analysis Database: Database Description and Users
-#' Manual Version 5.1.2 for Phase 2. U.S. Department of Agriculture.
-#' (http://fia.fs.fed.us/library/database-documentation/current/ver5-2012/FIADB_user
-#' manual_5-1-2_p2_07_2012.pdf)
-#' @source FIA look-up table
-#' @keywords datasets
-NULL
-
-
-
-
-#' Reference table - Metadata for shp_* default variables output from
-#' DBgetPlots()
-#' 
-#' Data frame with variable names and descriptions
-#' 
-#' 
-#' @name ref_shp
-#' @docType data
-#' @format A dataframe with 63 rows and 4 columns VARIABLE - Variable in plt
-#' data frame DESCRIPTION - Description of variable in plt data frame TABLE -
-#' Table in database where variable originates or if derived SHPEXPORT - Name
-#' of variable for exported shapefile (<= 10 characters)
-#' @references O'Connell, B.M.; LaPoint, E.B.; Turner, J.A.; Ridley, T.; Boyer,
-#' D.; Wilson, A.M.; Waddell, K.L.; Christensen, G.; Conkling, B.L. 2012. The
-#' Forest Inventory and Analysis Database: Database Description and Users
-#' Manual Version 5.1.2 for Phase 2. U.S. Department of Agriculture.
-#' (http://fia.fs.fed.us/library/database-documentation/current/ver5-2012/FIADB_user
-#' manual_5-1-2_p2_07_2012.pdf)
-#' @source FIA look-up table
-#' @keywords datasets
-NULL
-
-
-
-
-#' Reference tables - Code definitions.
-#' 
-#' Table with species information.
-#' 
-#' 
-#' @name ref_species
-#' @docType data
-#' @format A dataframe with 8 columns: SPCD, COMMON_NAME, GENUS, SPECIES,
-#' EXISTS_IN_NRCS, EXISTS_IN_NERS, EXISTS_IN_PNWRS, EXISTS_IN_RMRS,
-#' EXISTS_IN_SRS.
-#' @references O'Connell, B.M.; LaPoint, E.B.; Turner, J.A.; Ridley, T.; Boyer,
-#' D.; Wilson, A.M.; Waddell, K.L.; Christensen, G.; Conkling, B.L. 2012. The
-#' Forest Inventory and Analysis Database: Database Description and Users
-#' Manual Version 5.1.2 for Phase 2. U.S. Department of Agriculture.
-#' (http://fia.fs.fed.us/library/database-documentation/current/ver5-2012/FIADB_user
-#' manual_5-1-2_p2_07_2012.pdf)
-#' @source FIA look-up tables.
-#' @keywords datasets
-NULL
-
-
-
-#' Reference table - Variable titles.
-#' 
-#' Table with variable name (VARNM) and associated title (TITLE).
-#' 
-#' 
-#' @name ref_titles
-#' @docType data
-#' @format A dataframe with 2 columns, VARNM and TITLE.
-#' @source Comma-delimited file.
-#' @keywords datasets
-NULL
-
-
-#' Reference table - popType codes.
-#' 
-#' Table with population type (popType) and associated evaluation code (EVAL_TYP_CD).
-#' 
-#' 
-#' @name ref_popType
-#' @docType data
-#' @format A dataframe with 2 columns, VARNM and TITLE.
-#' @source Comma-delimited file.
-#' @keywords datasets
-NULL
-
-
-#' Reference table - Metadata for tree default variables output from
-#' DBgetPlots()
-#' 
-#' Data frame with variable names and descriptions
-#' 
-#' 
-#' @name ref_tree
-#' @docType data
-#' @format A data frame with 72 rows and 3 columns VARIABLE - Variable in tree
-#' data frame DESCRIPTION - Description of variable in tree data frame TABLE -
-#' Table in database where variable originates
-#' @references O'Connell, B.M.; LaPoint, E.B.; Turner, J.A.; Ridley, T.; Boyer,
-#' D.; Wilson, A.M.; Waddell, K.L.; Christensen, G.; Conkling, B.L. 2012. The
-#' Forest Inventory and Analysis Database: Database Description and Users
-#' Manual Version 5.1.2 for Phase 2. U.S. Department of Agriculture.
-#' (http://fia.fs.fed.us/library/database-documentation/current/ver5-2012/FIADB_user
-#' manual_5-1-2_p2_07_2012.pdf)
-#' @source FIA look-up table
-#' @keywords datasets
-NULL
-
-
 #' FIA data. Plot assignment data from FIA public database.
 #' 
 #' FIA plot-level stratification assignments for the state of Wyoming, FIA 
@@ -275,7 +84,6 @@ NULL
 NULL
 
 
-
 #' FIA data. Post-stratification data from FIA public database.
 #' 
 #' FIA stratification data for the state of Wyoming, FIA Evaluation 561301, 
