@@ -62,7 +62,7 @@ checktabs <- function(tabs, names) {
   ##########################################################  
   condnm=vsubpstrnm=vsubpsppnm=subplotnm=subp_condnm <- NULL
 
-  ## Check name of PLOT table
+  ## Check name of COND table
   pltnmchk <- checktabs(tabs, c("plt", "plot"))
   if (is.null(pltnmchk)) {
     message("plot data needed for estimates")
@@ -71,10 +71,9 @@ checktabs <- function(tabs, names) {
   if (is.character(tabs[[pltnmchk]])) {  
     pltnm <- tabs[[pltnmchk]]
   } else {
-    pltnm <- "pltx"
+    pltnm <- "plt"
   }
-  assign(pltnm, tabs[[pltnmchk]])
- 
+
   ## Check name of COND table
   condnmchk <- checktabs(tabs, "cond")
   if (is.null(condnmchk)) {
@@ -84,7 +83,7 @@ checktabs <- function(tabs, names) {
   if (is.character(tabs[[condnmchk]])) {  
     condnm <- tabs[[condnmchk]]
   } else {
-    condnm <- "condu"
+    condnm <- "cond"
   }
   assign(condnm, tabs[[condnmchk]])
   cuniqueid <- tabIDs[[condnmchk]]
@@ -204,11 +203,15 @@ checktabs <- function(tabs, names) {
 	}
 
     ## Get remeasured plot data
-    if (!is.null(pltnm)) {
-      assign(pltnm, pcheck.table(get(pltnm), tab_dsn=dsn, 
-           tabnm="plt", caption="Remeasured plot data?", 
-           nullcheck=nullcheck, gui=gui, returnsf=FALSE))
-	  pltflds <- names(get(pltnm))
+    if (!is.null(pltx)) {
+	  pltnm <- "pltx"
+	  pltflds <- names(pltx)
+	  
+      if (!pjoinid %in% pltflds) {
+	    if (puniqueid %in% pltflds) {
+		  pjoinid <- puniqueid
+		}
+	  }  
     } 
 
     ## Get subplot data for generating estimates
@@ -227,9 +230,11 @@ checktabs <- function(tabs, names) {
            nullcheck=nullcheck, gui=gui, returnsf=FALSE))
 
     ## Get vsubpspp data for generating estimates
-    assign(vsubpsppnm, pcheck.table(get(vsubpsppnm), tab_dsn=dsn, 
+	if (!is.null(vsubpsppnm)) {
+      assign(vsubpsppnm, pcheck.table(get(vsubpsppnm), tab_dsn=dsn, 
            tabnm="vsubpspp", caption="vsubpspp table?", 
            nullcheck=nullcheck, gui=gui, returnsf=FALSE))
+    }
   }  
 
   ## Build pfromqry
@@ -291,27 +296,26 @@ checktabs <- function(tabs, names) {
   ###################################################################################
   ## Import tables
   ###################################################################################
-  condx <- suppressMessages(pcheck.table(condnm, tab_dsn=dsn, 
-           tabnm="cond", caption="cond table?",
-		   tabqry=condqry, stopifnull=TRUE))
-
-  subplotx <- suppressMessages(pcheck.table(subplotnm, tab_dsn=dsn, 
-           tabnm="subplot", caption="subplot table?", 
-           tabqry=subplotqry, stopifnull=TRUE))
-		   
-  subp_condx <- suppressMessages(pcheck.table(subp_condnm, tab_dsn=dsn, 
-           tabnm="subp_cond", caption="subp_cond table?", 
-           tabqry=subp_condqry, stopifnull=TRUE))
-
-  if (!is.null(vsubpsppnm)) {
-    vsubpsppx <- suppressMessages(pcheck.table(vsubpsppnm, tab_dsn=dsn, 
-           tabnm="vsubpspp", caption="Veg Species table?", 
-           tabqry=vsubpsppqry, stopifnull=FALSE))
+  if (is.null(dbconn)) {
+    condx <- data.table(sqldf::sqldf(condqry, connection = NULL))
+    subplotx <- data.table(sqldf::sqldf(subplotqry, connection = NULL))
+    subp_condx <- data.table(sqldf::sqldf(subp_condqry, connection = NULL))
+    if (!is.null(vsubpsppnm)) {
+      vsubpsppx <- data.table(sqldf::sqldf(vsubpsppqry, connection = NULL))
+    }
+    vsubpstrx <- data.table(sqldf::sqldf(vsubpstrqry, connection = NULL))
+  } else {
+    ###################################################################################
+    ## Import tables
+    ###################################################################################
+    condx <- data.table(DBI::dbGetQuery(dbconn, condqry))
+    subplotx <- data.table(DBI::dbGetQuery(dbconn, subplotqry))
+    subp_condx <- data.table(DBI::dbGetQuery(dbconn, subp_condqry))
+    if (!is.null(vsubpsppnm)) {
+      vsubpsppx <- data.table(DBI::dbGetQuery(dbconn, vsubpsppqry))
+    }
+    vsubpstrx <- data.table(DBI::dbGetQuery(dbconn, vsubpstrqry))
   }
-  
-  vsubpstrx <- suppressMessages(pcheck.table(vsubpstrnm, tab_dsn=dsn, 
-           tabnm="vsubpstr", caption="Veg Structure table?", 
-           tabqry=vsubpstrqry, stopifnull=TRUE))
 
   ## Define cdoms2keep
   cdoms2keep <- names(condx)
@@ -453,7 +457,7 @@ checktabs <- function(tabs, names) {
       message("NF_COND_STATUS_CD not in dataset.. assuming all sampled nonforest conditions")
     }
   }
- 
+
   #############################################################################
   ## Generate and apply nonsamp.cfilter
   #############################################################################
@@ -486,7 +490,6 @@ checktabs <- function(tabs, names) {
     }
   }
 
-
   ###################################################################################
   ## Check area weight 
   ###################################################################################
@@ -651,7 +654,6 @@ checktabs <- function(tabs, names) {
   ## Merge summed subplot condition proportions to condx
   vcondx <- merge(condx, SUBP_CONDPROP_UNADJ)
 
-
   #############################################################################
   ## Check veg profile data (P2VEG_SUBPLOT_SPP, P2VEG_SUBP_STRUCTURE)
   #############################################################################
@@ -665,7 +667,7 @@ checktabs <- function(tabs, names) {
 		warn=paste(vsubpsppid, "not in vegspspp"), stopifnull=TRUE)
     cvars2keep <- c(cvars2keep, "SUBPCOND_PROP")
 
-    ## Check for NA values in necessary variables in tree table
+    ## Check for NA values in necessary variables in tree table;
     vsubpsppx.na <- sum(is.na(vsubpsppx[[vsubpsppid]]))
     if (vsubpsppx.na > 0) stop("NA values in ", vsubpsppid)
 
